@@ -294,7 +294,7 @@ def test_make_borg_snapshot_pattern_includes_slashdot_hack_and_stripped_pattern_
     )
 
 
-def test_dump_data_sources_snapshots_and_mounts_and_updates_patterns():
+def test_dump_data_sources_snapshots_and_mounts_and_replaces_patterns():
     config = {'lvm': {}}
     patterns = [Pattern('/mnt/lvolume1/subdir'), Pattern('/mnt/lvolume2')]
     logical_volumes = (
@@ -360,6 +360,22 @@ def test_dump_data_sources_snapshots_and_mounts_and_updates_patterns():
         logical_volumes[1],
         '/run/borgmatic',
     ).and_return(Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2'))
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/lvolume1/subdir'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume1/subdir',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/lvolume2'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -373,11 +389,6 @@ def test_dump_data_sources_snapshots_and_mounts_and_updates_patterns():
         == []
     )
 
-    assert patterns == [
-        Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume1/subdir'),
-        Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2'),
-    ]
-
 
 def test_dump_data_sources_with_no_logical_volumes_skips_snapshots():
     config = {'lvm': {}}
@@ -385,6 +396,7 @@ def test_dump_data_sources_with_no_logical_volumes_skips_snapshots():
     flexmock(module).should_receive('get_logical_volumes').and_return(())
     flexmock(module).should_receive('snapshot_logical_volume').never()
     flexmock(module).should_receive('mount_snapshot').never()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').never()
 
     assert (
         module.dump_data_sources(
@@ -398,8 +410,6 @@ def test_dump_data_sources_with_no_logical_volumes_skips_snapshots():
         == []
     )
 
-    assert patterns == [Pattern('/mnt/lvolume1/subdir'), Pattern('/mnt/lvolume2')]
-
 
 def test_dump_data_sources_uses_snapshot_size_for_snapshot():
     config = {'lvm': {'snapshot_size': '1000PB'}}
@@ -467,6 +477,22 @@ def test_dump_data_sources_uses_snapshot_size_for_snapshot():
         logical_volumes[1],
         '/run/borgmatic',
     ).and_return(Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2'))
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/lvolume1/subdir'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume1/subdir',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/lvolume2'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -480,11 +506,6 @@ def test_dump_data_sources_uses_snapshot_size_for_snapshot():
         == []
     )
 
-    assert patterns == [
-        Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume1/subdir'),
-        Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2'),
-    ]
-
 
 def test_dump_data_sources_uses_custom_commands():
     config = {
@@ -559,6 +580,22 @@ def test_dump_data_sources_uses_custom_commands():
         logical_volumes[1],
         '/run/borgmatic',
     ).and_return(Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2'))
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/lvolume1/subdir'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume1/subdir',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/lvolume2'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -572,11 +609,6 @@ def test_dump_data_sources_uses_custom_commands():
         == []
     )
 
-    assert patterns == [
-        Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume1/subdir'),
-        Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2'),
-    ]
-
 
 def test_dump_data_sources_with_dry_run_skips_snapshots_and_does_not_touch_patterns():
     config = {'lvm': {}}
@@ -601,6 +633,7 @@ def test_dump_data_sources_with_dry_run_skips_snapshots_and_does_not_touch_patte
     flexmock(module).should_receive('snapshot_logical_volume').never()
     flexmock(module).should_receive('get_snapshots').never()
     flexmock(module).should_receive('mount_snapshot').never()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').never()
 
     assert (
         module.dump_data_sources(
@@ -614,11 +647,6 @@ def test_dump_data_sources_with_dry_run_skips_snapshots_and_does_not_touch_patte
         == []
     )
 
-    assert patterns == [
-        Pattern('/mnt/lvolume1/subdir'),
-        Pattern('/mnt/lvolume2'),
-    ]
-
 
 def test_dump_data_sources_ignores_mismatch_between_given_patterns_and_contained_patterns():
     config = {'lvm': {}}
@@ -686,6 +714,22 @@ def test_dump_data_sources_ignores_mismatch_between_given_patterns_and_contained
         logical_volumes[1],
         '/run/borgmatic',
     ).and_return(Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2'))
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/lvolume1/subdir'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume1/subdir',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/lvolume2'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -699,12 +743,6 @@ def test_dump_data_sources_ignores_mismatch_between_given_patterns_and_contained
         == []
     )
 
-    assert patterns == [
-        Pattern('/hmm'),
-        Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume1/subdir'),
-        Pattern('/run/borgmatic/lvm_snapshots/b33f/./mnt/lvolume2'),
-    ]
-
 
 def test_dump_data_sources_with_missing_snapshot_errors():
     config = {'lvm': {}}
@@ -747,6 +785,7 @@ def test_dump_data_sources_with_missing_snapshot_errors():
         snapshot_name='lvolume2_borgmatic-1234',
     ).never()
     flexmock(module).should_receive('mount_snapshot').never()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').never()
 
     with pytest.raises(ValueError):
         module.dump_data_sources(
