@@ -21,6 +21,23 @@ def test_database_names_to_dump_passes_through_name():
     assert names == ('foo',)
 
 
+def test_database_names_to_dump_with_non_all_name_and_skip_names_warns():
+    environment = flexmock()
+
+    flexmock(module.logger).should_receive('warning').once()
+
+    names = module.database_names_to_dump(
+        {'name': 'foo', 'skip_names': ('foo', 'bar')},
+        {},
+        'root',
+        'trustsome1',
+        environment,
+        dry_run=False,
+    )
+
+    assert names == ('foo',)
+
+
 def test_database_names_to_dump_bails_for_dry_run():
     environment = flexmock()
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
@@ -75,6 +92,45 @@ def test_database_names_to_dump_queries_mysql_for_database_names():
     assert names == ('foo', 'bar')
 
 
+def test_database_names_to_dump_with_database_name_all_and_skip_names_filters_out_unwanted_databases():
+    environment = flexmock()
+    flexmock(module.borgmatic.hooks.credential.parse).should_receive(
+        'resolve_credential',
+    ).replace_with(lambda value, config: value)
+    flexmock(module.borgmatic.hooks.data_source.mariadb).should_receive(
+        'parse_extra_options'
+    ).and_return((), None)
+    flexmock(module.borgmatic.hooks.data_source.mariadb).should_receive(
+        'make_defaults_file_options'
+    ).with_args(
+        'root',
+        'trustsome1',
+        None,
+    ).and_return(('--defaults-extra-file=/dev/fd/99',))
+    flexmock(module).should_receive('execute_command_and_capture_output').with_args(
+        (
+            'mysql',
+            '--defaults-extra-file=/dev/fd/99',
+            '--skip-column-names',
+            '--batch',
+            '--execute',
+            'show schemas',
+        ),
+        environment=environment,
+    ).and_return('foo\nbar\nbaz\nmysql\n').once()
+
+    names = module.database_names_to_dump(
+        {'name': 'all', 'skip_names': ('foo', 'bar')},
+        {},
+        'root',
+        'trustsome1',
+        environment,
+        dry_run=False,
+    )
+
+    assert names == ('baz',)
+
+
 def test_database_names_to_dump_with_environment_password_transport_skips_defaults_file_and_passes_user_flag():
     environment = flexmock()
     flexmock(module.borgmatic.hooks.credential.parse).should_receive(
@@ -240,6 +296,13 @@ def test_dump_data_sources_dumps_each_database():
             module.borgmatic.actions.restore.Dump('mysql_databases', 'bar'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mysql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -289,6 +352,13 @@ def test_dump_data_sources_dumps_with_password():
             module.borgmatic.actions.restore.Dump('mysql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mysql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         [database],
@@ -340,6 +410,13 @@ def test_dump_data_sources_dumps_with_environment_password_transport_passes_pass
             module.borgmatic.actions.restore.Dump('mysql_databases', 'foo'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mysql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         [database],
@@ -379,6 +456,13 @@ def test_dump_data_sources_dumps_all_databases_at_once():
             module.borgmatic.actions.restore.Dump('mysql_databases', 'all'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mysql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert module.dump_data_sources(
         databases,
@@ -421,6 +505,13 @@ def test_dump_data_sources_dumps_all_databases_separately_when_format_configured
             module.borgmatic.actions.restore.Dump('mysql_databases', 'bar'),
         ],
     ).once()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').with_args(
+        object,
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/mysql_databases',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -446,6 +537,7 @@ def test_dump_data_sources_errors_for_missing_all_databases():
         'databases/localhost/all',
     )
     flexmock(module).should_receive('database_names_to_dump').and_return(())
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').never()
 
     with pytest.raises(ValueError):
         assert module.dump_data_sources(
@@ -469,6 +561,7 @@ def test_dump_data_sources_does_not_error_for_missing_all_databases_with_dry_run
         'databases/localhost/all',
     )
     flexmock(module).should_receive('database_names_to_dump').and_return(())
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('inject_pattern').never()
 
     assert (
         module.dump_data_sources(
