@@ -1,5 +1,3 @@
-import os
-
 import pytest
 from flexmock import flexmock
 
@@ -302,7 +300,7 @@ def test_make_borg_snapshot_pattern_includes_slashdot_hack_and_stripped_pattern_
     )
 
 
-def test_dump_data_sources_snapshots_and_mounts_and_updates_patterns():
+def test_dump_data_sources_snapshots_and_mounts_and_replaces_patterns():
     dataset = flexmock(
         name='dataset',
         mount_point='/mnt/dataset',
@@ -330,6 +328,14 @@ def test_dump_data_sources_snapshots_and_mounts_and_updates_patterns():
         '/run/borgmatic',
     ).and_return(Pattern('/run/borgmatic/zfs_snapshots/b33f/./mnt/dataset/subdir'))
     patterns = [Pattern('/mnt/dataset/subdir')]
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/dataset/subdir'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/zfs_snapshots/b33f/./mnt/dataset/subdir',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
 
     assert (
         module.dump_data_sources(
@@ -343,14 +349,13 @@ def test_dump_data_sources_snapshots_and_mounts_and_updates_patterns():
         == []
     )
 
-    assert patterns == [Pattern(os.path.join(snapshot_mount_path, 'subdir'))]
-
 
 def test_dump_data_sources_with_no_datasets_skips_snapshots():
     flexmock(module).should_receive('get_datasets_to_backup').and_return(())
     flexmock(module.os).should_receive('getpid').and_return(1234)
     flexmock(module).should_receive('snapshot_dataset').never()
     flexmock(module).should_receive('mount_snapshot').never()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').never()
     patterns = [Pattern('/mnt/dataset')]
 
     assert (
@@ -395,6 +400,14 @@ def test_dump_data_sources_uses_custom_commands():
         dataset,
         '/run/borgmatic',
     ).and_return(Pattern('/run/borgmatic/zfs_snapshots/b33f/./mnt/dataset/subdir'))
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/dataset/subdir'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/zfs_snapshots/b33f/./mnt/dataset/subdir',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
     patterns = [Pattern('/mnt/dataset/subdir')]
     hook_config = {
         'zfs_command': '/usr/local/bin/zfs',
@@ -416,8 +429,6 @@ def test_dump_data_sources_uses_custom_commands():
         == []
     )
 
-    assert patterns == [Pattern(os.path.join(snapshot_mount_path, 'subdir'))]
-
 
 def test_dump_data_sources_with_dry_run_skips_commands_and_does_not_touch_patterns():
     flexmock(module).should_receive('get_datasets_to_backup').and_return(
@@ -426,6 +437,7 @@ def test_dump_data_sources_with_dry_run_skips_commands_and_does_not_touch_patter
     flexmock(module.os).should_receive('getpid').and_return(1234)
     flexmock(module).should_receive('snapshot_dataset').never()
     flexmock(module).should_receive('mount_snapshot').never()
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').never()
     patterns = [Pattern('/mnt/dataset')]
 
     assert (
@@ -440,8 +452,6 @@ def test_dump_data_sources_with_dry_run_skips_commands_and_does_not_touch_patter
         == []
     )
 
-    assert patterns == [Pattern('/mnt/dataset')]
-
 
 def test_dump_data_sources_ignores_mismatch_between_given_patterns_and_contained_patterns():
     dataset = flexmock(
@@ -470,6 +480,14 @@ def test_dump_data_sources_ignores_mismatch_between_given_patterns_and_contained
         dataset,
         '/run/borgmatic',
     ).and_return(Pattern('/run/borgmatic/zfs_snapshots/b33f/./mnt/dataset/subdir'))
+    flexmock(module.borgmatic.hooks.data_source.config).should_receive('replace_pattern').with_args(
+        object,
+        Pattern('/mnt/dataset/subdir'),
+        module.borgmatic.borg.pattern.Pattern(
+            '/run/borgmatic/zfs_snapshots/b33f/./mnt/dataset/subdir',
+            source=module.borgmatic.borg.pattern.Pattern_source.HOOK,
+        ),
+    ).once()
     patterns = [Pattern('/hmm')]
 
     assert (
@@ -484,8 +502,6 @@ def test_dump_data_sources_ignores_mismatch_between_given_patterns_and_contained
         == []
     )
 
-    assert patterns == [Pattern('/hmm'), Pattern(os.path.join(snapshot_mount_path, 'subdir'))]
-
 
 def test_get_all_snapshots_parses_list_output():
     flexmock(module.borgmatic.execute).should_receive(
